@@ -170,7 +170,7 @@ reg_estimators = [
 txt_cls = '''
 from sklearn.linear_model import LogisticRegression
 from sklearn.ensemble import RandomForestClassifier
-from sklearn.ensemble import AdaBoostClassifier, GradientBoostingClassifier, ExtraTreesClassifier, HistGradientBoostingClassifier
+from sklearn.ensemble import AdaBoostClassifier, GradientBoostingClassifier, ExtraTreesClassifier
 from xgboost import XGBClassifier
 from lightgbm import LGBMClassifier
 
@@ -920,7 +920,7 @@ from sklearn.ensemble import GradientBoostingClassifier
 from xgboost import XGBClassifier
 from lightgbm import LGBMClassifier
 from sklearn.ensemble import ExtraTreesClassifier
-from sklearn.ensemble import HistGradientBoostingClassifier
+# from sklearn.ensemble import HistGradientBoostingClassifier
 
 from sklearn.ensemble import AdaBoostClassifier
 from sklearn.tree import DecisionTreeClassifier
@@ -942,8 +942,8 @@ cls_estimators = [
         reg_alpha=0, reg_lambda=1, is_unbalance=True),
     ExtraTreesClassifier(n_estimators=100, max_depth=5, criterion='entropy', 
         min_samples_split=2, n_jobs=-1),
-    HistGradientBoostingClassifier(min_samples_leaf=1, max_bins = 255,
-        learning_rate=1, max_iter=100),
+    # HistGradientBoostingClassifier(min_samples_leaf=1, max_bins = 255,
+    #     learning_rate=1, max_iter=100),
 
     MLPClassifier(max_iter=100, alpha=0.1, verbose=False, early_stopping=True,
         hidden_layer_sizes=(100, 10)),
